Module uim.codec.format.WILL_2_0_0_pb2
======================================
Generated protocol buffer code.

Classes
-------

`ParticlesPaint(*args, **kwargs)`
:   A ProtocolMessage

    ### Ancestors (in MRO)

    * google.protobuf.pyext._message.CMessage
    * google.protobuf.message.Message

    ### Class variables

    `DESCRIPTOR`
    :

    `NONE`
    :

    `RANDOM`
    :

    `Rotation`
    :

    `TRAJECTORY`
    :

    ### Instance variables

    `compositeOperation`
    :   Field WacomInkFormat.ParticlesPaint.compositeOperation

    `fill`
    :   Field WacomInkFormat.ParticlesPaint.fill

    `fillHeight`
    :   Field WacomInkFormat.ParticlesPaint.fillHeight

    `fillWidth`
    :   Field WacomInkFormat.ParticlesPaint.fillWidth

    `id`
    :   Field WacomInkFormat.ParticlesPaint.id

    `randomizeFill`
    :   Field WacomInkFormat.ParticlesPaint.randomizeFill

    `rotation`
    :   Field WacomInkFormat.ParticlesPaint.rotation

    `scattering`
    :   Field WacomInkFormat.ParticlesPaint.scattering

    `shape`
    :   Field WacomInkFormat.ParticlesPaint.shape

    `spacing`
    :   Field WacomInkFormat.ParticlesPaint.spacing

`Path(*args, **kwargs)`
:   A ProtocolMessage

    ### Ancestors (in MRO)

    * google.protobuf.pyext._message.CMessage
    * google.protobuf.message.Message

    ### Class variables

    `DESCRIPTOR`
    :

    ### Instance variables

    `compositeOperation`
    :   Field WacomInkFormat.Path.compositeOperation

    `data`
    :   Field WacomInkFormat.Path.data

    `decimalPrecision`
    :   Field WacomInkFormat.Path.decimalPrecision

    `endParameter`
    :   Field WacomInkFormat.Path.endParameter

    `id`
    :   Field WacomInkFormat.Path.id

    `startParameter`
    :   Field WacomInkFormat.Path.startParameter

    `strokeColor`
    :   Field WacomInkFormat.Path.strokeColor

    `strokePaint`
    :   Field WacomInkFormat.Path.strokePaint

    `strokeParticlesRandomSeed`
    :   Field WacomInkFormat.Path.strokeParticlesRandomSeed

    `strokeWidth`
    :   Field WacomInkFormat.Path.strokeWidth